chitose.com.atproto.identity package
====================================

Submodules
----------

chitose.com.atproto.identity.resolve\_handle module
---------------------------------------------------

.. automodule:: chitose.com.atproto.identity.resolve_handle
   :members:
   :undoc-members:
   :show-inheritance:

chitose.com.atproto.identity.update\_handle module
--------------------------------------------------

.. automodule:: chitose.com.atproto.identity.update_handle
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: chitose.com.atproto.identity
   :members:
   :undoc-members:
   :show-inheritance:
